pub fn update_params<T, C>(
params: &mut MinterParams<C>,
param_msg: UpdateMinterParamsMsg<T>,
) -> Result<(), ContractError>Expand description
Base update params that can be used by other minter factories
pub fn update_params<T, C>(
params: &mut MinterParams<C>,
param_msg: UpdateMinterParamsMsg<T>,
) -> Result<(), ContractError>Base update params that can be used by other minter factories